==> funes-0.2.0.crate: funes-0.2.0/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

## [0.2.0](https://github.com/rodmoioliveira/funes/compare/0.1.11...0.2.0) - 2021-09-09

[5915b85](https://github.com/rodmoioliveira/funes/commit/5915b8559236ec24456570b97c68416c25d4cb21)...[b12fb1e](https://github.com/rodmoioliveira/funes/commit/b12fb1eb58ae1373057fcbfc1fad4735b0dbd862)

### Features

- Implement latency_collection ([1b82c72](https://github.com/rodmoioliveira/funes/commit/1b82c72510321923a4387e790bcca925105728e3))

### Miscellaneous Tasks

- 0.2.0 ([b12fb1e](https://github.com/rodmoioliveira/funes/commit/b12fb1eb58ae1373057fcbfc1fad4735b0dbd862))

## [0.1.11](https://github.com/rodmoioliveira/funes/compare/0.1.10...0.1.11) - 2021-09-03

[d196756](https://github.com/rodmoioliveira/funes/commit/d1967560337ef19f8295021512845544d748843f)...[5915b85](https://github.com/rodmoioliveira/funes/commit/5915b8559236ec24456570b97c68416c25d4cb21)

### Miscellaneous Tasks

- Update CHANGELOG ([6239c8c](https://github.com/rodmoioliveira/funes/commit/6239c8c9a22da8c0c11d659b79e1d47360d8e4ef))
- 0.1.11 ([5915b85](https://github.com/rodmoioliveira/funes/commit/5915b8559236ec24456570b97c68416c25d4cb21))

## [0.1.10](https://github.com/rodmoioliveira/funes/compare/0.1.9...0.1.10) - 2021-09-03

[7b611ce](https://github.com/rodmoioliveira/funes/commit/7b611ce5a4940837c31faa411873f19cf03545c4)...[d196756](https://github.com/rodmoioliveira/funes/commit/d1967560337ef19f8295021512845544d748843f)

### Miscellaneous Tasks

- Set_var RUST_LOG ([a88ee38](https://github.com/rodmoioliveira/funes/commit/a88ee38941b0c6d27455218587a539636d7f9ae5))
- 0.1.10 ([d196756](https://github.com/rodmoioliveira/funes/commit/d1967560337ef19f8295021512845544d748843f))

## [0.1.9](https://github.com/rodmoioliveira/funes/compare/0.1.8...0.1.9) - 2021-09-03

[9368c7e](https://github.com/rodmoioliveira/funes/commit/9368c7efceaf123747c3bf62117d41ea18f20f87)...[7b611ce](https://github.com/rodmoioliveira/funes/commit/7b611ce5a4940837c31faa411873f19cf03545c4)

### Documentation

- Add docs.rs docs ([a01e139](https://github.com/rodmoioliveira/funes/commit/a01e139299d013ed9af092fb250a48852080c328))

### Miscellaneous Tasks

- Update CHANGELOG ([2d98fed](https://github.com/rodmoioliveira/funes/commit/2d98fede8567f66f851ddf2baa740d99d1e3a9e8))
- Update README ([2a969bc](https://github.com/rodmoioliveira/funes/commit/2a969bc4791bcf5d45ecf3a6f79f095cf9ff8f31))
- 0.1.9 ([7b611ce](https://github.com/rodmoioliveira/funes/commit/7b611ce5a4940837c31faa411873f19cf03545c4))

## [0.1.8](https://github.com/rodmoioliveira/funes/compare/0.1.7...0.1.8) - 2021-09-03

[543f119](https://github.com/rodmoioliveira/funes/commit/543f1196e711e80c176bedf82df43b9bb8ae6526)...[9368c7e](https://github.com/rodmoioliveira/funes/commit/9368c7efceaf123747c3bf62117d41ea18f20f87)

### Miscellaneous Tasks

- Update CHANGELOG ([f9e855c](https://github.com/rodmoioliveira/funes/commit/f9e855cac5bdc222aaf19655ffcbc5f349450bb8))
- Update README ([cb5a94a](https://github.com/rodmoioliveira/funes/commit/cb5a94a381235f2df11a58111462e9afb7f7d6f2))
- 0.1.8 ([9368c7e](https://github.com/rodmoioliveira/funes/commit/9368c7efceaf123747c3bf62117d41ea18f20f87))

## [0.1.7](https://github.com/rodmoioliveira/funes/compare/0.1.6...0.1.7) - 2021-09-03

[5513065](https://github.com/rodmoioliveira/funes/commit/5513065d30edc8b9fdda8002e80a1b013b114a6c)...[543f119](https://github.com/rodmoioliveira/funes/commit/543f1196e711e80c176bedf82df43b9bb8ae6526)

### Miscellaneous Tasks

- Update CHANGELOG ([fc4a27d](https://github.com/rodmoioliveira/funes/commit/fc4a27d41fb4dbde8ab97c58758ce39c4c31faad))
- Update manifest ([33e45db](https://github.com/rodmoioliveira/funes/commit/33e45dbe235a67f0418b73943e164c4983c39eef))
- Remove criterion ([72f26ff](https://github.com/rodmoioliveira/funes/commit/72f26ff03732e3b9e033abe3d1825b0d965c17d1))
- 0.1.7 ([543f119](https://github.com/rodmoioliveira/funes/commit/543f1196e711e80c176bedf82df43b9bb8ae6526))

## [0.1.6](https://github.com/rodmoioliveira/funes/compare/0.1.5...0.1.6) - 2021-09-02

[4f844be](https://github.com/rodmoioliveira/funes/commit/4f844be0f64dd4fe252d4c86fea64ea885ab99ea)...[5513065](https://github.com/rodmoioliveira/funes/commit/5513065d30edc8b9fdda8002e80a1b013b114a6c)

### Miscellaneous Tasks

- Update CHANGELOG ([5792da7](https://github.com/rodmoioliveira/funes/commit/5792da7547d8a5ebee5da646f4f3dd7c44e3ddc4))

### Refactor

- Change modules visibility ([885f978](https://github.com/rodmoioliveira/funes/commit/885f978e1187c5c875e6c015068a2367a99dc522))
- Rename errors ([9601971](https://github.com/rodmoioliveira/funes/commit/960197119a5726ee2bfc491d27f6d191fdd25c9f))
- Rename MyError to FunesError ([5513065](https://github.com/rodmoioliveira/funes/commit/5513065d30edc8b9fdda8002e80a1b013b114a6c))

## [0.1.5](https://github.com/rodmoioliveira/funes/compare/0.1.4...0.1.5) - 2021-09-01

[8706c66](https://github.com/rodmoioliveira/funes/commit/8706c66999af01e87ec29f7b45865cbacb7d3b9d)...[4f844be](https://github.com/rodmoioliveira/funes/commit/4f844be0f64dd4fe252d4c86fea64ea885ab99ea)

### Bug Fixes

- Fix tests ([cdf4ac0](https://github.com/rodmoioliveira/funes/commit/cdf4ac0a6b5526a43e220d3c03f3285a541cdbe9))

### Features

- Create io namespace ([d9b3033](https://github.com/rodmoioliveira/funes/commit/d9b303348475e964d9f9505c2a5610bef9fed444))
- Rename functions ([71e84a1](https://github.com/rodmoioliveira/funes/commit/71e84a1c4bbf667e0102bf4898ac02be3d551979))
- Create format namespace ([98cd047](https://github.com/rodmoioliveira/funes/commit/98cd04726480b84af63dae4c76cd0e4b9308b179))

### Miscellaneous Tasks

- Update CHANGELOG ([36119a1](https://github.com/rodmoioliveira/funes/commit/36119a165104804c722d084021f2832fc3428dd1))
- Rename check_mocks_dir() to mock_dir() ([4f844be](https://github.com/rodmoioliveira/funes/commit/4f844be0f64dd4fe252d4c86fea64ea885ab99ea))

### Testing

- Add tests post_api and get_api ([19e1601](https://github.com/rodmoioliveira/funes/commit/19e16017bbf6fa6c0dd7af0169c104d123fac510))

## [0.1.4](https://github.com/rodmoioliveira/funes/compare/0.1.3...0.1.4) - 2021-09-01

[5e1c60a](https://github.com/rodmoioliveira/funes/commit/5e1c60a65e9e53b83ca93b35efaa2ca86da8dc83)...[8706c66](https://github.com/rodmoioliveira/funes/commit/8706c66999af01e87ec29f7b45865cbacb7d3b9d)

### Bug Fixes

- Remove status route ([137c205](https://github.com/rodmoioliveira/funes/commit/137c205c45ad231655160dd5d5a1409f8fe07d6d))
- Remove convert_headers() and headers from reqwest ([8706c66](https://github.com/rodmoioliveira/funes/commit/8706c66999af01e87ec29f7b45865cbacb7d3b9d))

### CI

- Create rust.yml ([b4d03b1](https://github.com/rodmoioliveira/funes/commit/b4d03b1a252c2a4c43bc506bf14cbe42e2cf2288))

### Features

- Create RUST_MOCK_DIR env ([c495255](https://github.com/rodmoioliveira/funes/commit/c495255d920808f87fe322db4c6ca74a3fa5b827))

### Miscellaneous Tasks

- Update CHANGELOG ([9d76977](https://github.com/rodmoioliveira/funes/commit/9d769771f3e84a4f9ebedc7438bce5d7848ff4b4))
- Add pipeline workflow badge ([527cb44](https://github.com/rodmoioliveira/funes/commit/527cb44a5071c5d8383224a74d378d0db98ad755))
- Remove some .clone()s ([918be20](https://github.com/rodmoioliveira/funes/commit/918be20a9fbce9069b3f52f781b71149c600d6a1))

## [0.1.3](https://github.com/rodmoioliveira/funes/compare/0.1.2...0.1.3) - 2021-08-31

[be52bc1](https://github.com/rodmoioliveira/funes/commit/be52bc18ff14306fd5ece0947a7f1302e902fc41)...[5e1c60a](https://github.com/rodmoioliveira/funes/commit/5e1c60a65e9e53b83ca93b35efaa2ca86da8dc83)

### Features

- Add docker example ([5e1c60a](https://github.com/rodmoioliveira/funes/commit/5e1c60a65e9e53b83ca93b35efaa2ca86da8dc83))

## [0.1.2](https://github.com/rodmoioliveira/funes/compare/0.1.1...0.1.2) - 2021-08-31

[13f8f4c](https://github.com/rodmoioliveira/funes/commit/13f8f4cd2218b2653072567df1a1f69e02e84d2b)...[be52bc1](https://github.com/rodmoioliveira/funes/commit/be52bc18ff14306fd5ece0947a7f1302e902fc41)

### Bug Fixes

- Fix CHANGELOG links ([05779c0](https://github.com/rodmoioliveira/funes/commit/05779c026f1a86ebda90b7c6f036dc9aaf6cbe0b))
- Fix headers for client and server ([be52bc1](https://github.com/rodmoioliveira/funes/commit/be52bc18ff14306fd5ece0947a7f1302e902fc41))

### Miscellaneous Tasks

- Update CHANGELOG ([e36c6bd](https://github.com/rodmoioliveira/funes/commit/e36c6bddabc35f4d7cc65f145b091fed22b0d1e5))

## [0.1.1](https://github.com/rodmoioliveira/funes/compare/0.1.0...0.1.1) - 2021-08-31

[d2cda58](https://github.com/rodmoioliveira/funes/commit/d2cda5867210f84aa84b6e943d23ea3016b219f4)...[13f8f4c](https://github.com/rodmoioliveira/funes/commit/13f8f4cd2218b2653072567df1a1f69e02e84d2b)

### CI

- Update ([9b64399](https://github.com/rodmoioliveira/funes/commit/9b643997dcac1296d02b6ec4e6ab3e8fc304ff7a))

### Miscellaneous Tasks

- Add README badges ([deebf84](https://github.com/rodmoioliveira/funes/commit/deebf845269c25719164cbb31250f2f323db2991))
- Add Borges quote ([b937823](https://github.com/rodmoioliveira/funes/commit/b937823af3adfc7589dd03ec5d1c90adb882dd75))
- Improve documentation ([13f8f4c](https://github.com/rodmoioliveira/funes/commit/13f8f4cd2218b2653072567df1a1f69e02e84d2b))

## [0.1.0](https://github.com/rodmoioliveira/funes/compare/...0.1.0) - 2021-08-30

### Miscellaneous Tasks

- First commit ([d2cda58](https://github.com/rodmoioliveira/funes/commit/d2cda5867210f84aa84b6e943d23ea3016b219f4))

<!-- generated by git-cliff -->

==> funes-0.2.1.crate: funes-0.2.1/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

## [0.2.1](https://github.com/rodmoioliveira/funes/compare/0.2.0...0.2.1) - 2021-09-09

[b12fb1e](https://github.com/rodmoioliveira/funes/commit/b12fb1eb58ae1373057fcbfc1fad4735b0dbd862)...[8a04042](https://github.com/rodmoioliveira/funes/commit/8a04042455a68e05f9847347493a743e5b20a816)

### Documentation

- Improve docs ([483f93a](https://github.com/rodmoioliveira/funes/commit/483f93ad41c347eb8059ec6fdcb79c979a45fb39))

### Miscellaneous Tasks

- Update CHANGELOG ([5aa9aa4](https://github.com/rodmoioliveira/funes/commit/5aa9aa450f00f248bb49301b27d241613efbb4ae))
- Update Cargo.lock ([f821f5c](https://github.com/rodmoioliveira/funes/commit/f821f5c169e3d026459d4b79d52f41e807892df4))
- Update latency-collection examples ([4d1a18d](https://github.com/rodmoioliveira/funes/commit/4d1a18d9693ec16b3ebd74b531f706c928c02fa0))
- Set default FUNES_MOCK_DIR as $HOME/.mocks ([36cfba0](https://github.com/rodmoioliveira/funes/commit/36cfba06ae844f72b92d28f245ec46244cb2a3b4))
- Remove log::debug! ([3051a35](https://github.com/rodmoioliveira/funes/commit/3051a35ab8eb138ca1f82d592a0e6597eb57938f))
- Default of FUNES_LATENCY_COLLECTION is "" ([558789c](https://github.com/rodmoioliveira/funes/commit/558789cfb03e1587258daad3bf6a6679adb86cc9))
- 0.2.1 ([8a04042](https://github.com/rodmoioliveira/funes/commit/8a04042455a68e05f9847347493a743e5b20a816))

## [0.2.0](https://github.com/rodmoioliveira/funes/compare/0.1.11...0.2.0) - 2021-09-09

[5915b85](https://github.com/rodmoioliveira/funes/commit/5915b8559236ec24456570b97c68416c25d4cb21)...[b12fb1e](https://github.com/rodmoioliveira/funes/commit/b12fb1eb58ae1373057fcbfc1fad4735b0dbd862)

### Features

- Implement latency_collection ([1b82c72](https://github.com/rodmoioliveira/funes/commit/1b82c72510321923a4387e790bcca925105728e3))

### Miscellaneous Tasks

- 0.2.0 ([b12fb1e](https://github.com/rodmoioliveira/funes/commit/b12fb1eb58ae1373057fcbfc1fad4735b0dbd862))

## [0.1.11](https://github.com/rodmoioliveira/funes/compare/0.1.10...0.1.11) - 2021-09-03

[d196756](https://github.com/rodmoioliveira/funes/commit/d1967560337ef19f8295021512845544d748843f)...[5915b85](https://github.com/rodmoioliveira/funes/commit/5915b8559236ec24456570b97c68416c25d4cb21)

### Miscellaneous Tasks

- Update CHANGELOG ([6239c8c](https://github.com/rodmoioliveira/funes/commit/6239c8c9a22da8c0c11d659b79e1d47360d8e4ef))
- 0.1.11 ([5915b85](https://github.com/rodmoioliveira/funes/commit/5915b8559236ec24456570b97c68416c25d4cb21))

## [0.1.10](https://github.com/rodmoioliveira/funes/compare/0.1.9...0.1.10) - 2021-09-03

[7b611ce](https://github.com/rodmoioliveira/funes/commit/7b611ce5a4940837c31faa411873f19cf03545c4)...[d196756](https://github.com/rodmoioliveira/funes/commit/d1967560337ef19f8295021512845544d748843f)

### Miscellaneous Tasks

- Set_var RUST_LOG ([a88ee38](https://github.com/rodmoioliveira/funes/commit/a88ee38941b0c6d27455218587a539636d7f9ae5))
- 0.1.10 ([d196756](https://github.com/rodmoioliveira/funes/commit/d1967560337ef19f8295021512845544d748843f))

## [0.1.9](https://github.com/rodmoioliveira/funes/compare/0.1.8...0.1.9) - 2021-09-03

[9368c7e](https://github.com/rodmoioliveira/funes/commit/9368c7efceaf123747c3bf62117d41ea18f20f87)...[7b611ce](https://github.com/rodmoioliveira/funes/commit/7b611ce5a4940837c31faa411873f19cf03545c4)

### Documentation

- Add docs.rs docs ([a01e139](https://github.com/rodmoioliveira/funes/commit/a01e139299d013ed9af092fb250a48852080c328))

### Miscellaneous Tasks

- Update CHANGELOG ([2d98fed](https://github.com/rodmoioliveira/funes/commit/2d98fede8567f66f851ddf2baa740d99d1e3a9e8))
- Update README ([2a969bc](https://github.com/rodmoioliveira/funes/commit/2a969bc4791bcf5d45ecf3a6f79f095cf9ff8f31))
- 0.1.9 ([7b611ce](https://github.com/rodmoioliveira/funes/commit/7b611ce5a4940837c31faa411873f19cf03545c4))

## [0.1.8](https://github.com/rodmoioliveira/funes/compare/0.1.7...0.1.8) - 2021-09-03

[543f119](https://github.com/rodmoioliveira/funes/commit/543f1196e711e80c176bedf82df43b9bb8ae6526)...[9368c7e](https://github.com/rodmoioliveira/funes/commit/9368c7efceaf123747c3bf62117d41ea18f20f87)

### Miscellaneous Tasks

- Update CHANGELOG ([f9e855c](https://github.com/rodmoioliveira/funes/commit/f9e855cac5bdc222aaf19655ffcbc5f349450bb8))
- Update README ([cb5a94a](https://github.com/rodmoioliveira/funes/commit/cb5a94a381235f2df11a58111462e9afb7f7d6f2))
- 0.1.8 ([9368c7e](https://github.com/rodmoioliveira/funes/commit/9368c7efceaf123747c3bf62117d41ea18f20f87))

## [0.1.7](https://github.com/rodmoioliveira/funes/compare/0.1.6...0.1.7) - 2021-09-03

[5513065](https://github.com/rodmoioliveira/funes/commit/5513065d30edc8b9fdda8002e80a1b013b114a6c)...[543f119](https://github.com/rodmoioliveira/funes/commit/543f1196e711e80c176bedf82df43b9bb8ae6526)

### Miscellaneous Tasks

- Update CHANGELOG ([fc4a27d](https://github.com/rodmoioliveira/funes/commit/fc4a27d41fb4dbde8ab97c58758ce39c4c31faad))
- Update manifest ([33e45db](https://github.com/rodmoioliveira/funes/commit/33e45dbe235a67f0418b73943e164c4983c39eef))
- Remove criterion ([72f26ff](https://github.com/rodmoioliveira/funes/commit/72f26ff03732e3b9e033abe3d1825b0d965c17d1))
- 0.1.7 ([543f119](https://github.com/rodmoioliveira/funes/commit/543f1196e711e80c176bedf82df43b9bb8ae6526))

## [0.1.6](https://github.com/rodmoioliveira/funes/compare/0.1.5...0.1.6) - 2021-09-02

[4f844be](https://github.com/rodmoioliveira/funes/commit/4f844be0f64dd4fe252d4c86fea64ea885ab99ea)...[5513065](https://github.com/rodmoioliveira/funes/commit/5513065d30edc8b9fdda8002e80a1b013b114a6c)

### Miscellaneous Tasks

- Update CHANGELOG ([5792da7](https://github.com/rodmoioliveira/funes/commit/5792da7547d8a5ebee5da646f4f3dd7c44e3ddc4))

### Refactor

- Change modules visibility ([885f978](https://github.com/rodmoioliveira/funes/commit/885f978e1187c5c875e6c015068a2367a99dc522))
- Rename errors ([9601971](https://github.com/rodmoioliveira/funes/commit/960197119a5726ee2bfc491d27f6d191fdd25c9f))
- Rename MyError to FunesError ([5513065](https://github.com/rodmoioliveira/funes/commit/5513065d30edc8b9fdda8002e80a1b013b114a6c))

## [0.1.5](https://github.com/rodmoioliveira/funes/compare/0.1.4...0.1.5) - 2021-09-01

[8706c66](https://github.com/rodmoioliveira/funes/commit/8706c66999af01e87ec29f7b45865cbacb7d3b9d)...[4f844be](https://github.com/rodmoioliveira/funes/commit/4f844be0f64dd4fe252d4c86fea64ea885ab99ea)

### Bug Fixes

- Fix tests ([cdf4ac0](https://github.com/rodmoioliveira/funes/commit/cdf4ac0a6b5526a43e220d3c03f3285a541cdbe9))

### Features

- Create io namespace ([d9b3033](https://github.com/rodmoioliveira/funes/commit/d9b303348475e964d9f9505c2a5610bef9fed444))
- Rename functions ([71e84a1](https://github.com/rodmoioliveira/funes/commit/71e84a1c4bbf667e0102bf4898ac02be3d551979))
- Create format namespace ([98cd047](https://github.com/rodmoioliveira/funes/commit/98cd04726480b84af63dae4c76cd0e4b9308b179))

### Miscellaneous Tasks

- Update CHANGELOG ([36119a1](https://github.com/rodmoioliveira/funes/commit/36119a165104804c722d084021f2832fc3428dd1))
- Rename check_mocks_dir() to mock_dir() ([4f844be](https://github.com/rodmoioliveira/funes/commit/4f844be0f64dd4fe252d4c86fea64ea885ab99ea))

### Testing

- Add tests post_api and get_api ([19e1601](https://github.com/rodmoioliveira/funes/commit/19e16017bbf6fa6c0dd7af0169c104d123fac510))

## [0.1.4](https://github.com/rodmoioliveira/funes/compare/0.1.3...0.1.4) - 2021-09-01

[5e1c60a](https://github.com/rodmoioliveira/funes/commit/5e1c60a65e9e53b83ca93b35efaa2ca86da8dc83)...[8706c66](https://github.com/rodmoioliveira/funes/commit/8706c66999af01e87ec29f7b45865cbacb7d3b9d)

### Bug Fixes

- Remove status route ([137c205](https://github.com/rodmoioliveira/funes/commit/137c205c45ad231655160dd5d5a1409f8fe07d6d))
- Remove convert_headers() and headers from reqwest ([8706c66](https://github.com/rodmoioliveira/funes/commit/8706c66999af01e87ec29f7b45865cbacb7d3b9d))

### CI

- Create rust.yml ([b4d03b1](https://github.com/rodmoioliveira/funes/commit/b4d03b1a252c2a4c43bc506bf14cbe42e2cf2288))

### Features

- Create RUST_MOCK_DIR env ([c495255](https://github.com/rodmoioliveira/funes/commit/c495255d920808f87fe322db4c6ca74a3fa5b827))

### Miscellaneous Tasks

- Update CHANGELOG ([9d76977](https://github.com/rodmoioliveira/funes/commit/9d769771f3e84a4f9ebedc7438bce5d7848ff4b4))
- Add pipeline workflow badge ([527cb44](https://github.com/rodmoioliveira/funes/commit/527cb44a5071c5d8383224a74d378d0db98ad755))
- Remove some .clone()s ([918be20](https://github.com/rodmoioliveira/funes/commit/918be20a9fbce9069b3f52f781b71149c600d6a1))

## [0.1.3](https://github.com/rodmoioliveira/funes/compare/0.1.2...0.1.3) - 2021-08-31

[be52bc1](https://github.com/rodmoioliveira/funes/commit/be52bc18ff14306fd5ece0947a7f1302e902fc41)...[5e1c60a](https://github.com/rodmoioliveira/funes/commit/5e1c60a65e9e53b83ca93b35efaa2ca86da8dc83)

### Features

- Add docker example ([5e1c60a](https://github.com/rodmoioliveira/funes/commit/5e1c60a65e9e53b83ca93b35efaa2ca86da8dc83))

## [0.1.2](https://github.com/rodmoioliveira/funes/compare/0.1.1...0.1.2) - 2021-08-31

[13f8f4c](https://github.com/rodmoioliveira/funes/commit/13f8f4cd2218b2653072567df1a1f69e02e84d2b)...[be52bc1](https://github.com/rodmoioliveira/funes/commit/be52bc18ff14306fd5ece0947a7f1302e902fc41)

### Bug Fixes

- Fix CHANGELOG links ([05779c0](https://github.com/rodmoioliveira/funes/commit/05779c026f1a86ebda90b7c6f036dc9aaf6cbe0b))
- Fix headers for client and server ([be52bc1](https://github.com/rodmoioliveira/funes/commit/be52bc18ff14306fd5ece0947a7f1302e902fc41))

### Miscellaneous Tasks

- Update CHANGELOG ([e36c6bd](https://github.com/rodmoioliveira/funes/commit/e36c6bddabc35f4d7cc65f145b091fed22b0d1e5))

## [0.1.1](https://github.com/rodmoioliveira/funes/compare/0.1.0...0.1.1) - 2021-08-31

[d2cda58](https://github.com/rodmoioliveira/funes/commit/d2cda5867210f84aa84b6e943d23ea3016b219f4)...[13f8f4c](https://github.com/rodmoioliveira/funes/commit/13f8f4cd2218b2653072567df1a1f69e02e84d2b)

### CI

- Update ([9b64399](https://github.com/rodmoioliveira/funes/commit/9b643997dcac1296d02b6ec4e6ab3e8fc304ff7a))

### Miscellaneous Tasks

- Add README badges ([deebf84](https://github.com/rodmoioliveira/funes/commit/deebf845269c25719164cbb31250f2f323db2991))
- Add Borges quote ([b937823](https://github.com/rodmoioliveira/funes/commit/b937823af3adfc7589dd03ec5d1c90adb882dd75))
- Improve documentation ([13f8f4c](https://github.com/rodmoioliveira/funes/commit/13f8f4cd2218b2653072567df1a1f69e02e84d2b))

## [0.1.0](https://github.com/rodmoioliveira/funes/compare/...0.1.0) - 2021-08-30

### Miscellaneous Tasks

- First commit ([d2cda58](https://github.com/rodmoioliveira/funes/commit/d2cda5867210f84aa84b6e943d23ea3016b219f4))

<!-- generated by git-cliff -->
